==> qt-components-hildon_0.1.1.tar.gz: qt-components-hildon-0.1.1/src/components/window_p_p.h <==
/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef WINDOW_P_P_H
#define WINDOW_P_P_H

#include "item_p_p.h"
#include "window_p.h"

class WindowPrivate : ItemPrivate
{

public:
    WindowPrivate(Window *parent) :
        ItemPrivate(parent),
        orientation(Screen::LandscapeOrientation)
    {
    }

    static void data_append(QDeclarativeListProperty<QObject> *list, QObject *obj);

    static void actions_append(QDeclarativeListProperty<QObject> *list, QObject *obj);

    static void tools_append(QDeclarativeListProperty<QObject> *list, QObject *obj);

    QDeclarativeListProperty<QObject> data();

    QDeclarativeListProperty<QObject> actions();

    QDeclarativeListProperty<QObject> tools();

    void componentComplete();

    Screen::Orientation orientation;

    QList<QObject*> toolList;

    Q_DECLARE_PUBLIC(Window)
};

#endif // WINDOW_P_P_H

==> qt-components-hildon_0.8.0.tar.gz: qt-components-hildon-0.8.0/src/components/window_p_p.h <==
/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef WINDOW_P_P_H
#define WINDOW_P_P_H

#include "item_p_p.h"
#include "window_p.h"
#include "pagestack_p.h"

class PageStack;

class WindowPrivate : ItemPrivate
{

public:
    WindowPrivate(Window *parent) :
        ItemPrivate(parent),
        pageStack(new PageStack(parent)),
        orientation(Screen::LandscapeOrientation)
    {
    }

    static void data_append(QDeclarativeListProperty<QObject> *list, QObject *obj);

    static void children_append(QDeclarativeListProperty<QWidget> *list, QWidget *widget);

    static void actions_append(QDeclarativeListProperty<QObject> *list, QObject *obj);

    static void tools_append(QDeclarativeListProperty<QObject> *list, QObject *obj);

    QDeclarativeListProperty<QObject> data();

    QDeclarativeListProperty<QWidget> children();

    QDeclarativeListProperty<QObject> actions();

    QDeclarativeListProperty<QObject> tools();

    void componentComplete();

    PageStack *pageStack;

    Screen::Orientation orientation;

    QList<QObject*> toolList;

    Q_DECLARE_PUBLIC(Window)
};

#endif // WINDOW_P_P_H
